@@ -1,5 +1,5 @@
 """Main module."""
-from typing import List
+from typing import List, Union
 
 import grpc
 
@@ -7,6 +7,31 @@ from wemopy import internal
 from wemopy.internal import rules_pb2, rules_pb2_grpc
 from wemopy.types import RuleFieldValues, ReorderValues, LossValues, JitterValues
 
+def convert_rate_to_int(rate:str) -> int:
+    numeric = ""
+    suffix = ""
+
+    for c in rate:
+        if c.isnumeric():
+            numeric += c
+        elif c.isalpha():
+            suffix += c
+
+    multiplier = 0
+    if suffix.lower().startswith("b"):
+        multiplier = 0
+    elif suffix.lower().startswith("k"):
+        multiplier = 1000
+    elif suffix.lower().startswith("m"):
+        multiplier = 1000 * 1000
+    elif suffix.lower().startswith("g"):
+        multiplier = 1000 * 1000 * 1000
+    elif suffix.lower().startswith("t"):
+        multiplier = 1000 * 1000 * 1000 * 1000
+    elif suffix.lower().startswith("p"):
+        multiplier = 1000 * 1000 * 1000 * 1000 * 1000
+
+    return int(int(numeric) * multiplier)
 
 class WEMOClient(object):
 
@@ -152,7 +177,7 @@ class WEMOClient(object):
                         reorder_corr=reorder_corr, ul_reorder_corr=ul_reorder_corr, dl_reorder_corr=dl_reorder_corr,
                         clear=clear)
 
-    def set(self, rule_id:int=1, name:str=None, enabled:bool=None, rate:int=None, ul_rate:int=None, dl_rate:int=None,
+    def set(self, rule_id:int=1, name:str=None, enabled:bool=None, rate:Union[int,str]=None, ul_rate:int=None, dl_rate:int=None,
             latency:float=None, ul_latency:float=None, dl_latency:float=None, jitter:float=None, ul_jitter:float=None,
             dl_jitter:float=None, jitter_dist:str=None, ul_jitter_dist:str=None, dl_jitter_dist:str=None,
             jitter_corr:float=None, ul_jitter_corr:float=None, dl_jitter_corr:float=None, loss:float=None,
@@ -178,13 +203,22 @@ class WEMOClient(object):
         if any(v is not None for v in [rate, ul_rate, dl_rate]):
 
             if rate is not None:
-                rule.ul_rate = rate / 2
-                rule.dl_rate = rate / 2
+                if isinstance(rate, str):
+                    rate = convert_rate_to_int(rate)
+
+                rule.ul_rate = int(rate)
+                rule.dl_rate = int(rate)
 
             if ul_rate is not None:
+                if isinstance(ul_rate, str):
+                    rate = convert_rate_to_int(ul_rate)
+
                 rule.ul_rate = ul_rate
 
             if dl_rate is not None:
+                if isinstance(dl_rate, str):
+                    rate = convert_rate_to_int(dl_rate)
+
                 rule.dl_rate = dl_rate
 
         # Latency
